/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package examples.invoice.persistclass;

import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PBinding;
import org.objectweb.jorm.api.PException;

import java.io.Serializable;

/**
 * @author	P. Dechamboux
 */
public class Product implements PAccessor, ProductAccessor {
	private String name;
	private char size;
	private String color;
	private float weight;
	private float price;
	private String picture; // stored as a serialized object
	private PBinding pBinding;

	public PBinding getPBinding() {
		return pBinding;
	}

	/**
	 * Creates a new Address.
	 */
	public Product(Object conn, PBinding pb, String n, char s, String c, float w, float p) throws PException {
		pBinding = pb;
		name = n;
		size = s;
		color = (c == null) ? "black" : c;
		weight = w;
		price = p;
		picture = "My Picture";
		pBinding.export(conn);
		pBinding.write(conn, this);
	}

	/**
	 * Creates a Product that is already persistent.
	 */
	public Product(Object conn, PBinding pb) throws PException {
		pBinding = pb;
		pb.read(conn, this);
	}

	/**
	 * Turns this persistent object into a non-persistent one.
	 */
	public void delete(Object conn) throws PException {
		pBinding.unexport(conn);
		pBinding.write(conn, this);
		pBinding = null;
	}

	/**
	 * Yields a printable version a the full Address.
	 */
	public String toPrintable() throws PException {
		return "ID: [" + pBinding.getPName().encodeString() + "] - VALUE: [name: " + name + ", size: " + size + ", color: " + color + ", weight: " + weight + "kg, price: " + price + "euros, picture: (" + picture + ")]";
	}

	// IMPLEMENTATION OF PAccessor INTERFACE

	public Object getMemoryInstance() {
		return this;
	}

	// IMPLEMENTATION OF AddressAccessor INTERFACE (generated by JORM)

	// Accessors to the name field
	public void paSetName(String val) throws PException {
		name = val;
	}

	public String paGetName() throws PException {
		return name;
	}

	// Accessors to the size field
	public void paSetSize(char val) throws PException {
		size = val;
	}

	public char paGetSize() throws PException {
		return size;
	}

	// Accessors to the color field
	public void paSetColor(String val) throws PException {
		color = val;
	}

	public String paGetColor() throws PException {
		return color;
	}

	// Accessors to the weight field
	public void paSetWeight(float val) throws PException {
		weight = val;
	}

	public float paGetWeight() throws PException {
		return weight;
	}

	// Accessors to the price field
	public void paSetPrice(float val) throws PException {
		price = val;
	}

	public float paGetPrice() throws PException {
		return price;
	}
	// Accessors to the picture field
	public void paSetPicture(Serializable val) throws PException {
		picture = (String) val;
	}

	public Serializable paGetPicture() throws PException {
		return picture;
	}
}
