/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
public class OneOneBi extends JormcRunner {

    public final static String PROJECT_NAME = "jormExamples";
    public final static String A_CLASS_NAME = "org.objectweb.jorm.examples.oob.A";
    public final static String B_CLASS_NAME = "org.objectweb.jorm.examples.oob.B";


    public static void main(String[] args) {
        try {
            OneOneBi oob = new OneOneBi(args.length == 0 ? "./" : args[0]);
            logger.log(BasicLevel.INFO, "Example OneOneBi");
            oob.createMIofA();
            oob.createMIofB();
            oob.generate();
        } catch (Exception e) {
            logger.log(BasicLevel.ERROR, "", getInner(e));
        }
    }
    public OneOneBi(String output) throws PException {
        super(PROJECT_NAME, output);
    }

    public void createMIofA() throws PException {
        logger.log(BasicLevel.INFO, "Create the meta information of the A class");
        Class aclass = compiler.getMIManager().createClass(A_CLASS_NAME);

        PrimitiveElement ida =
                aclass.createPrimitiveElement("ida", PTypeSpace.LONG);
        PrimitiveElement f1 =
                        aclass.createPrimitiveElement("f1", PTypeSpace.STRING);

        // pk simple
        NameDef aNameDef = aclass.createNameDef();
        aNameDef.setFieldName("ida");

        // reference to B
        ScalarField idb = aclass.createHiddenField("idb", PTypeSpace.LONG);
        Class bclass = compiler.getMIManager().createClass(B_CLASS_NAME);
        ClassRef bcr = aclass.createClassRef("myB", bclass);
        NameDef myBNameDef = bcr.createRefNameDef();
        myBNameDef.setFieldName(idb.getName());

        // ----------------- Mapping for A -----------------
        ClassProject acp = aclass.createClassProject(PROJECT_NAME);
        RdbMapping am = (RdbMapping) acp.createMapping("rdb");

        RdbClassMapping acm = am.createClassMapping("to-table");
        RdbTable tableA = acm.createRdbTable("table_A");
        //Identifier of the A class
        acm.createIdentifierMapping(aNameDef);

        // Mapping rule of the reference myB
        acm.createReferenceMapping("embedded-target-reference", myBNameDef);

        // Mapping of the ida field over the pka_col
        tableA.createPrimitiveElementMapping(ida, "pka_col", null, true);
        // Mapping of the f1 field over the f1_col
        tableA.createPrimitiveElementMapping(f1, "f1_col", null, true);
        // Mapping of the idb field over the fkb_col
        tableA.createPrimitiveElementMapping(idb, "fkb_col", null, false);
    }

    public void createMIofB() throws PException {
        logger.log(BasicLevel.INFO, "Create the meta information of the B class");
        Class bclass = compiler.getMIManager().createClass(B_CLASS_NAME);
        PrimitiveElement idb =
                bclass.createPrimitiveElement("idb", PTypeSpace.LONG);
        PrimitiveElement f2 =
                bclass.createPrimitiveElement("f2", PTypeSpace.STRING);

        // pk simple
        NameDef bNameDef = bclass.createNameDef();
        bNameDef.setFieldName(idb.getName());

        // reference to A
        ScalarField ida = bclass.createHiddenField("ida", PTypeSpace.LONG);
        Class aclass = compiler.getMIManager().createClass(A_CLASS_NAME);
        ClassRef acr = bclass.createClassRef("myA", aclass);
        NameDef myANameDef = acr.createRefNameDef();
        myANameDef.setFieldName(ida.getName());

        // ----------------- Mapping for B -----------------

        ClassProject bcp = bclass.createClassProject(PROJECT_NAME);
        RdbMapping bm = (RdbMapping) bcp.createMapping("rdb");

        RdbClassMultiMapping bcm = bm.createClassMultiMapping("to-table");
        RdbTable tableB = bcm.createRdbTable("table_B");
        bcm.createIdentifierMapping(bNameDef);

        bcm.createReferenceMapping("multi-table", myANameDef);

        tableB.createPrimitiveElementMapping(idb, "pkb_col", null, true);
        tableB.createPrimitiveElementMapping(f2, "f2_col", null, true);

        //Mapping of the reference to A
        RdbExternalTable extTableA = bcm.createRdbExternalTable("table_A");
        extTableA.setReadOnly(true); // optimisation to avoid writings
        extTableA.createPrimitiveElementMapping(ida, "pka_col");
        RdbJoin joinToA = extTableA.createRdbJoin("myA_Join");
        joinToA.addJoinColumnNames("pkb_col", "fkb_col");
    }
}
