/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.api;

import org.objectweb.jorm.type.api.PExceptionTyping;
import org.objectweb.jorm.naming.api.PNameCoder;

/**
 * @author	P. Dechamboux
 */
public interface PClassMappingCtrl {
	/**
	 * It assigns the PNameCoder used to manage the references hold by a
	 * generic class instance whose mapping is described by this PClassMapping.
	 * It should verify that the name structure for this reference is supported
	 * by the corresponding naming context.
	 * @param pnc	The PNameCoder to be associated to this generic class
	 * 				PClassMapping for managing its reference elements.
	 * @exception	PExceptionTyping	It is raised when the structure of the
	 * 									the names that reference the DSI stored
	 * 									within the generic class instance is not
	 * 									supported by this naming context.
	 * @exception	UnsupportedOperationException	It is raised when this
	 * 												PClassMapping does not map
	 * 												a generic class instance, or
	 * 												when the elements of this
	 * 												generic class instance are
	 * 												not references.
	 */
	void setPNameCoder(PNameCoder pnc)
			throws PException, UnsupportedOperationException;

	/**
	 * It assigns the PNameCoder used to manage the reference hold by a
	 * field whose type is a JORM class.
	 * It should verify that the name structure for this reference is supported
	 * by the corresponding naming context.
	 * @param fn	The name of the involved field.
	 * @param pnc	The PNameCoder to be associated to this field for
	 * 				managing the reference it may hold.
	 * @exception	PExceptionTyping	It is raised when the structure of the
	 * 									the names that reference the DSI stored
	 * 									within the generic class instance is not
	 * 									supported by this naming context.
	 * @exception	UnsupportedOperationException	It is raised when no naming
	 * 												context is associated to
	 * 												the corresponding field.
	 */
	void setPNameCoder(String fn, PNameCoder pnc)
			throws PException, UnsupportedOperationException;

	/**
	 * It assigns the PNameCoder to use for the class. This PNamingContext
	 * manages also the sub classes.
	 */ 
	void setClassPNameCoder(PNameCoder pnc) throws PException;

	/**
	 * It assigns the GenClassMapping used to manage the reference hold by a
	 * field whose type is a JORM gen class.
	 */
	void setGenClassMapping(PClassMapping pcm)
			throws UnsupportedOperationException;

	/**
	 * It assigns the GenClassMapping used to manage the reference hold by a
	 * field whose type is a JORM class.
	 */
	void setGenClassMapping(String fn, PClassMapping pcm)
			throws UnsupportedOperationException;

	/**
	 * Assignes the project name to a PClassMapping.
	 * @param projectname to be assigned
	 */
	void setProjectName(String projectname);
}
