/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.compiler.api;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.JormConfigurator;
import org.objectweb.jorm.generator.api.Generator;
import org.objectweb.jorm.generator.api.MOPFactory;
import org.objectweb.jorm.verifier.api.MappingVerifier;
import org.objectweb.jorm.verifier.api.Verifier;

import java.io.InputStream;

/**
 * Used to hold the configuration information related to a JORM compiler
 * instance.
 * @author	P. Dechamboux
 */
public interface JormCompilerConfigurator extends JormConfigurator {
	final String LOGGER_NAME = "org.objectweb.jorm.compiler.config";
	final String DEFAULT_JORM_CONFIGURATION_FILE = "jorm.properties";
	final String USE_CONTEXT_CLASSLOADER = "use.context.classloader";

	/**
	 * Gets the verifier to be used by JORM.
	 * @return	That verifier.
	 */
	Verifier getVerifier() throws PException;

	/**
	 * Gets the generator to be used by JORM.
	 * @return	That generator.
	 */
	Generator getGenerator() throws PException;

	/**
	 * Gets the name to be used for the compiler options file.
	 * @return	That name.
	 */
	String getJormcOptsFile() throws PException;

	/**
	 * Gets the MOP factory associated with the given mapper.
	 * @param mappername	The name of the concerned mapper.
	 * @return The MOPFactory object.
	 * @throws PException
	 */
	MOPFactory getMOPFactory(String mappername) throws PException;

	/**
	 * Gets an InputStream for reading the global compiler parameters.
	 * @return  The allocated InputStream.
	 * @throws PException
	 */
	InputStream getGlobalJormcOptsFile() throws PException;

	/**
	 * Gets the verifier associated with the given mapper.
	 * @param mappername	The name of the concerned mapper.
	 * @return The MappingVerifier object.
	 * @throws PException
	 */
	MappingVerifier getMappingVerifier(String mappername) throws PException;
}
