/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.basidir;

import org.objectweb.jorm.metainfo.api.Class;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNamingContext;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.naming.api.PNameGetter;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.naming.api.PNameManager;
import org.objectweb.jorm.naming.api.PolymorphicPName;
import org.objectweb.jorm.naming.api.PolymorphicPNamingContext;
import org.objectweb.jorm.naming.lib.BasicPolymorphicPName;
import org.objectweb.jorm.naming.lib.BasicPName;
import org.objectweb.jorm.api.PException;

import java.util.Date;
import java.text.DateFormat;
import java.math.BigInteger;
import java.math.BigDecimal;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public class BasidName extends BasicPolymorphicPName implements PNameGetter {
	protected Object o = null;
	protected long p = 0;

	public BasidName(Object o, BasidBinder binder) throws PExceptionNaming {
		this(o, binder, binder.codingType);
	}
	
	public BasidName(Object o, PNameManager binder, int codingType) throws PExceptionNaming {
		this.pnc = binder;
		if (o instanceof BasidName) {
			this.o = ((BasidName) o).o;
			this.p = ((BasidName) o).p;

		} else if (o instanceof PName) {
			switch (codingType) {
			case PNamingContext.CTBYTE:
				p = ((PName) o).encodeByte();
				break;
			case PNamingContext.CTOBYTE:
				o = ((PName) o).encodeObyte();
				break;
			case PNamingContext.CTCHAR:
				p = ((PName) o).encodeChar();
				break;
			case PNamingContext.CTOCHAR:
				o = ((PName) o).encodeOchar();
				break;
			case PNamingContext.CTINT:
				p = ((PName) o).encodeInt();
				break;
			case PNamingContext.CTOINT:
				o = ((PName) o).encodeOint();
				break;
			case PNamingContext.CTLONG:
				p = ((PName) o).encodeLong();
				break;
			case PNamingContext.CTOLONG:
				o = ((PName) o).encodeOlong();
				break;
			case PNamingContext.CTSHORT:
				p = ((PName) o).encodeShort();
				break;
			case PNamingContext.CTOSHORT:
				o = ((PName) o).encodeOshort();
				break;
			case PNamingContext.CTDATE:
				o = ((PName) o).encodeDate();
				break;
			case PNamingContext.CTSTRING:
				o = ((PName) o).encodeString();
				break;
			case PNamingContext.CTBYTEARRAY:
				o = ((PName) o).encode();
				break;
			case PNamingContext.CTCHARARRAY:
				o = ((PName) o).encodeCharArray();
				break;
			default:
				throw new PExceptionNaming(
						"BasidName does not support this coding type");
			}

		} else if (o instanceof PNameGetter) {
			try {
				switch (codingType) {
				case PNameCoder.CTBYTE:
					p = ((PNameGetter) o).pngetByteField(null, null);
					break;
				case PNameCoder.CTOBYTE:
					o = ((PNameGetter) o).pngetObyteField(null, null);
					break;
				case PNameCoder.CTCHAR:
					p = ((PNameGetter) o).pngetCharField(null, null);
					break;
				case PNameCoder.CTOCHAR:
					o = ((PNameGetter) o).pngetOcharField(null, null);
					break;
				case PNameCoder.CTINT:
					p = ((PNameGetter) o).pngetIntField(null, null);
					break;
				case PNameCoder.CTOINT:
					o = ((PNameGetter) o).pngetOintField(null, null);
					break;
				case PNameCoder.CTLONG:
					p = ((PNameGetter) o).pngetLongField(null, null);
					break;
				case PNameCoder.CTOLONG:
					o = ((PNameGetter) o).pngetOlongField(null, null);
					break;
				case PNameCoder.CTSHORT:
					p = ((PNameGetter) o).pngetShortField(null, null);
					break;
				case PNameCoder.CTOSHORT:
					o = ((PNameGetter) o).pngetOshortField(null, null);
					break;
				case PNameCoder.CTDATE:
					o = ((PNameGetter) o).pngetDateField(null, null);
					break;
				case PNameCoder.CTSTRING:
					o = ((PNameGetter) o).pngetStringField(null, null);
					break;
				case PNameCoder.CTBYTEARRAY:
					o = ((PNameGetter) o).pngetByteArrayField(null, null);
					break;
				case PNameCoder.CTCHARARRAY:
					o = ((PNameGetter) o).pngetCharArrayField(null, null);
					break;
				default:
					throw new PExceptionNaming(
							"BasidName does not support this coding type");
				}
			} catch (PExceptionNaming e) {
				throw e;
			} catch (PException e) {
				throw new PExceptionNaming(e);
			}
		} else {
			switch (codingType) {
			case PNamingContext.CTBYTE:
			    if (o instanceof Byte) {
					this.p = ((Byte) o).byteValue();
			    } else if (o instanceof String) {
			        this.p = Byte.parseByte((String) o);
			    } else if (o instanceof Short) {
					this.p = ((Short) o).byteValue();
			    } else if (o instanceof Integer) {
					this.p = ((Integer) o).byteValue();
			    } else if (o instanceof Long) {
					this.p = ((Long) o).byteValue();
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Byte object value expected)");
				}
				break;
			case PNamingContext.CTCHAR:
				if (o instanceof Character) {
					this.p = ((Character) o).charValue();
			    } else if (o instanceof String) {
			        this.p = ((String) o).charAt(0);
				} else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Character object value expected)");
				}
				break;
			case PNamingContext.CTSHORT:
			    if (o instanceof Byte) {
					this.p = ((Byte) o).byteValue();
			    } else if (o instanceof String) {
			        this.p = Short.parseShort((String) o);
			    } else if (o instanceof Short) {
					this.p = ((Short) o).shortValue();
			    } else if (o instanceof Integer) {
					this.p = ((Integer) o).shortValue();
			    } else if (o instanceof Long) {
					this.p = ((Long) o).shortValue();
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Short object value expected)");
				}
				break;
			case PNamingContext.CTINT:
			    if (o instanceof Byte) {
					this.p = ((Byte) o).byteValue();
			    } else if (o instanceof String) {
			        this.p = Integer.parseInt((String) o);
			    } else if (o instanceof Short) {
					this.p = ((Short) o).shortValue();
			    } else if (o instanceof Integer) {
					this.p = ((Integer) o).intValue();
			    } else if (o instanceof Long) {
					this.p = ((Long) o).intValue();
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Integer object value expected)");
				}
				break;
			case PNamingContext.CTLONG:
			    if (o instanceof Byte) {
					this.p = ((Byte) o).byteValue();
			    } else if (o instanceof String) {
			        this.p = Long.parseLong((String) o);
			    } else if (o instanceof Short) {
					this.p = ((Short) o).shortValue();
			    } else if (o instanceof Integer) {
					this.p = ((Integer) o).intValue();
			    } else if (o instanceof Long) {
					this.p = ((Long) o).longValue();
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Long object value expected)");
				}
				break;
			case PNamingContext.CTOCHAR:
			    if (o == null || o instanceof Character) {
			        this.o = o;
			    } else if (o instanceof String) {
			        this.o = new Character(((String) o).charAt(0));
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Character object value expected)");
				}
				break;
			case PNamingContext.CTOBYTE:
			    if (o == null || o instanceof Byte) {
					this.o = o;
			    } else if (o instanceof String) {
			        this.o = Byte.decode((String) o);
			    } else if (o instanceof Short) {
					this.o = new Byte(((Short) o).byteValue());
			    } else if (o instanceof Integer) {
					this.o = new Byte(((Integer) o).byteValue());
			    } else if (o instanceof Long) {
					this.o = new Byte(((Long) o).byteValue());
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Byte object value expected)");
				}
				break;
			case PNamingContext.CTOSHORT:
			    if (o == null || o instanceof Short) {
					this.o = o;
			    } else if (o instanceof String) {
			        this.o = Short.decode((String) o);
			    } else if (o instanceof Byte) {
					this.o = new Short(((Byte) o).byteValue());
			    } else if (o instanceof Integer) {
					this.o = new Short(((Integer) o).shortValue());
			    } else if (o instanceof Long) {
					this.o = new Short(((Long) o).shortValue());
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Byte object value expected)");
				}
				break;
			case PNamingContext.CTOINT:
			    if (o == null || o instanceof Integer) {
					this.o = o;
			    } else if (o instanceof String) {
			        this.o = Integer.decode((String) o);
			    } else if (o instanceof Byte) {
					this.o = new Integer(((Byte) o).byteValue());
			    } else if (o instanceof Short) {
					this.o = new Integer(((Short) o).shortValue());
			    } else if (o instanceof Long) {
					this.o = new Integer(((Long) o).intValue());
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Integer object value expected)");
				}
				break;
			case PNamingContext.CTOLONG:
			    if (o == null || o instanceof Long) {
					this.o = o;
			    } else if (o instanceof String) {
			        this.o = Long.decode((String) o);
			    } else if (o instanceof Byte) {
					this.o = new Long(((Byte) o).byteValue());
			    } else if (o instanceof Short) {
					this.o = new Long(((Short) o).shortValue());
			    } else if (o instanceof Integer) {
					this.o = new Long(((Integer) o).intValue());
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Long object value expected)");
				}
				break;
			case PNamingContext.CTDATE:
		    	if (o == null || o instanceof Date) {
					this.o = o;
		    	} else if (o instanceof Long) {
					this.o = new Date(((Long) o).longValue());
			    } else if (o instanceof String) {
			        try {
				        this.o = new Date(Long.decode((String) o).longValue());
			        } catch (Exception e) {
				        try {
				            this.o = DateFormat.getInstance().parse((String) o);
				        } catch (Exception e2) {
							throw new PExceptionNaming(e2, "Cannot initalize BasidName with null value (Date object value expected)");
				        }
			        }
			    } else {
					throw new PExceptionNaming("Cannot initalize BasidName with null value (Date object value expected)");
				}
			default:
				this.o = o;
			}
		}
	}

	public BasidName(long p, BasidBinder binder) {
		this.pnc = binder;
		this.p = p;
	}

	// IMPLEMENTATION OF METHODS OF THE Object INTERFACE

	public boolean equals(Object obj) {
		if (obj instanceof BasidName) {
	    	BasidName pn = (BasidName) obj;
    		PolymorphicPName polymThis = (PolymorphicPName) this;
    		PolymorphicPName polymObj = (PolymorphicPName) pn;
    		//this or obj can be polymorphic
	    	if (polymThis.isPolymorphic() || polymObj.isPolymorphic()) {
	    		return (o != null	? o.equals(pn.o) : p == pn.p);
    		}	
	    }
		return (this == obj)
				|| ((obj instanceof BasidName)
				&& pnc == ((BasidName) obj).pnc
				&& (o != null
				? o.equals(((BasidName) obj).o)
				: p == ((BasidName) obj).p));
	}

	public int hashCode() {
		if (o != null)
			return o.hashCode();
		return (int) p;
	}

	public String toString() {
		BasidBinder basidBinder = null;
		if (pnc instanceof PolymorphicPNamingContext) {
			PolymorphicPNamingContext polymophicPNC = (PolymorphicPNamingContext) pnc;
			
			basidBinder = (BasidBinder) polymophicPNC.getDelegatedBinder();
		} else {
			basidBinder = (BasidBinder) pnc;
		}
		switch (basidBinder.codingType) {
		case PNamingContext.CTBYTE:
			return super.toString() + " / type=byte / value=" + p;
		case PNamingContext.CTCHAR:
			return super.toString() + " / type=char / value=" + (char) p;
		case PNamingContext.CTINT:
			return super.toString() + " / type=int / value=" + p;
		case PNamingContext.CTLONG:
			return super.toString() + " / type=long / value=" + p;
		case PNamingContext.CTSHORT:
			return super.toString() + " / type=short / value=" + p;
		default:
			return super.toString() + " / type=" + basidBinder.codingType
					+ " / value=" + o;
		}
	}

	// IMPLEMENTATION OF METHODS OF THE PName INTERFACE

	public boolean isNull() {
		BasidBinder basidBinder = null;
		if (pnc instanceof PolymorphicPNamingContext) {
			PolymorphicPNamingContext polymophicPNC = (PolymorphicPNamingContext) pnc;
			
			basidBinder = (BasidBinder) polymophicPNC.getDelegatedBinder();
		} else {
			basidBinder = (BasidBinder) pnc;
		}
		switch (basidBinder.codingType) {
		case PNamingContext.CTBYTE:
		case PNamingContext.CTCHAR:
		case PNamingContext.CTINT:
		case PNamingContext.CTLONG:
		case PNamingContext.CTSHORT:
			return p == basidBinder.nullValue;
		default:
			return o == basidBinder.nullOValue;
		}
	}

	public byte pngetByteField(String fn, Object ctxt) throws PException {
		return (byte) p;
	}

	public Byte pngetObyteField(String fn, Object ctxt) throws PException {
		return (Byte) o;
	}

	public char pngetCharField(String fn, Object ctxt) throws PException {
		return (char) p;
	}

	public Character pngetOcharField(String fn, Object ctxt) throws PException {
		return (Character) o;
	}

	public short pngetShortField(String fn, Object ctxt) throws PException {
		return (short) p;
	}

	public Short pngetOshortField(String fn, Object ctxt) throws PException {
		return (Short) o;
	}

	public int pngetIntField(String fn, Object ctxt) throws PException {
		return (int) p;
	}

	public Integer pngetOintField(String fn, Object ctxt) throws PException {
		return (Integer) o;
	}

	public long pngetLongField(String fn, Object ctxt) throws PException {
		return p;
	}

	public Long pngetOlongField(String fn, Object ctxt) throws PException {
		return (Long) o;
	}

	public String pngetStringField(String fn, Object ctxt) throws PException {
		return (String) o;
	}

	public byte[] pngetByteArrayField(String fn, Object ctxt) throws PException {
		return (byte[]) o;
	}

	public char[] pngetCharArrayField(String fn, Object ctxt) throws PException {
		return (char[]) o;
	}

	public Date pngetDateField(String fn, Object ctxt) throws PException {
		return (Date) o;
	}

	public BigInteger pngetBigIntegerField(String fn, Object ctxt) throws PException {
		return (BigInteger) o;
	}

	public BigDecimal pngetBigDecimalField(String fn, Object ctxt) throws PException {
		return (BigDecimal) o;
	}
}
