/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.polymorphid;

import org.objectweb.jorm.api.PMapper;
import org.objectweb.jorm.api.PException;

import java.util.HashMap;

/**
 * Statically registers PolymorphIdMgr associated with mappers within a JVM
 * context.
 * @author	P. Dechamboux
 */
public class PolymorphIdMgrRegistry {
	static HashMap mgrs = new HashMap();

	/**
	 * Removes this PolymorphIdMgr from this registry.
	 */
	public static void deregisterPolymorphIdMgr(PolymorphIdMgr pim) {
		mgrs.remove(pim.getPMapper());
	}

	/**
	 * Looks for a PolymorphIdMgr associated with this mapper.
	 */
	public static PolymorphIdMgr getPolymorphIdMgr(PMapper m) {
		PolymorphIdMgr res;
		res = (PolymorphIdMgr) mgrs.get(m);
		return res;
	}

	/**
	 * Adds this PolymorphIdMgr from this registry.
	 */
	public static synchronized void registerPolymorphIdMgr(PolymorphIdMgr pim)
			throws PException {
		if (mgrs.get(pim.getPMapper()) != null) {
			throw new PException("PolymorphIdMgr already registered.");
		}
		mgrs.put(pim.getPMapper(), pim);
	}
}
