/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.jorm.facility.naming.rdbsequence;

/**
 * Defines an identifier allocator based on a SQL sequence. This permits to
 * support the inheritance with the use of a SQL sequence. Indeed, an identifier
 * value MUST permit to find the class type of the persistent object. Then a way
 * respect this constraint and to have an identifier allocation based on a
 * sequence, is to modify the long value provided by the sequence in order to
 * code the class identifier into the object identifier. This can be done by
 * using one or several bits of the long value (in low or high position) for
 * example.
 *
 * @author S.Chassande-Barrioz
 */
public interface SequenceIdAllocator {

	/**
	 * Allocate an identifier from a new computed sequence value, and the naming
	 * key of the persistant class.
	 * @param key is the value that you have put in the 'inheritance-key'
	 * extension.
	 */
	long allocateId(long seqValue, Object key);

}
