/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.generator.lib;

import org.apache.velocity.VelocityContext;
import org.apache.velocity.context.Context;
import org.objectweb.jorm.compiler.api.PExceptionCompiler;
import org.objectweb.jorm.compiler.api.JormCompilerParameter;
import org.objectweb.jorm.metainfo.api.Class;
import org.objectweb.jorm.metainfo.api.Package;
import org.objectweb.jorm.util.io.api.TargetHolder;
import org.objectweb.jorm.api.PException;
import org.objectweb.util.monolog.api.BasicLevel;

import java.io.File;
import java.io.FileWriter;
import java.util.Iterator;

/**
 * This class is a generator of XXXAccessor objects. It is generic either the
 * mapper type. This generator use the velocity tools. The used template is
 * Accessor.vm . Associated to this template this generator builds a velocity
 * context which contains the following information:<br/>
 * <table border=1>
 * 	<tr><td>Key</td><td>Value</td></tr>
 * 	<tr><td>"class"</td><td>The reference to the Class meta object</td></tr>
 * 	<tr>
 * 		<td>"tools"</td>
 * 		<td>The reference to the <a href="CommonHelper.html">CommonHelper<a/></td>
 * </tr>
 * 	<tr>
 * 		<td>"header"</td>
 * 		<td>The file name of the common template which contains the header of
 * 			the generate files.</td>
 * </tr>
 * </table>
 */
public class AccessorGenerator extends CommonGenerator {
	/**
	 * This method generates a XAccessor file corresponding to the pod
	 * parameter in the directory parameter.
	 * @param co		The meta object interface.
	 * @param holder	The target holder which allows to create files.
	 * @param cp		This parameter permits to reach the compilation parameters.
	 */
	public void generate(Class co,
						 TargetHolder holder,
						 JormCompilerParameter cp) throws PException {
		// Calculate fileName
		String packName = ((Package) co.getParent()).getName();
		String fileName = co.getName() + "Accessor";
		if (packName != null && packName.length() > 0) {
			fileName = packName + "." + fileName;
			fileName = fileName.replace('.', File.separatorChar);
		}
		logger.log(BasicLevel.DEBUG, "Generate the " + fileName + " interface");
		Context ctx = new VelocityContext();
		ctx.put("class", co);
		CommonHelper ch = new CommonHelper();
		ch.setLogger(logger);
		ctx.put("tools", ch);
		ctx.put("header", GEN_TEMPLATE_DIR + "Header.vm");

		StringBuffer extension = new StringBuffer("PAccessor");
		Iterator it = co.getSuperClasses().iterator();
		if (it.hasNext()) {
			while(it.hasNext()) {
				extension.append(", ");
				extension.append(((Class) it.next()).getFQName());
				extension.append("Accessor");
			}
		}
		ctx.put("extension", extension);

		try {
			// Fetch a block with the fileName
			FileWriter fw = holder.getFileWriter(fileName + ".java");
			//load only once the template
			if (template == null) {
				template = velocityEngine.getTemplate(GEN_TEMPLATE_DIR + "Accessor.vm");
			}
			template.merge(ctx, fw);
			fw.flush();
			fw.close();
		} catch (Exception e) {
			throw new PExceptionCompiler(e, "Problem while generating PAccessor.");
		}
	}
}
