/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.genclass;

import org.objectweb.jorm.genclass.api.FieldDesc;
import org.objectweb.jorm.mapper.rdb.adapter.api.RdbAdapter;
import org.objectweb.jorm.api.PNameIterator;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.PExceptionIO;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.PreparedStatement;
import java.util.NoSuchElementException;

/**
 * It is an iterator over a resultset. The next() method returns the PName.
 * @author S. Chassande-Barrioz
 */
public class RdbGenClassPNGIterator
		extends RdbGenClassNameGetter
		implements PNameIterator {

	private boolean hasNext;
	private boolean isForw;
	private RdbGenClassMapping gcm;
	/**
	 *  indicates if the prefetching is activated.
	 */
	private boolean prefetching;

	public RdbGenClassPNGIterator(PreparedStatement ps,
	                              ResultSet rs,
	                              FieldDesc[] rfds,
								  RdbGenClassMapping gcm,
	                              boolean prefetching, 
	                              RdbAdapter adapter) throws SQLException {
		super(ps, rs, rfds, 0, adapter);
		this.prefetching = prefetching;
		this.gcm = gcm;
		hasNext = resultSet.next();
		isForw = true;
	}

	public boolean hasNext() {
		if (!isForw) {
			try {
				hasNext = resultSet.next();
			} catch (SQLException e) {
				e.printStackTrace();
				hasNext = false;
			}
			isForw = true;
		}
		return hasNext;
	}

	public Object next() throws NoSuchElementException {
		try {
			if (!isForw) {
				hasNext = resultSet.next();
				isForw = true;
			}
			if (!hasNext) {
				throw new NoSuchElementException();
			}
			isForw = false;
			return (elemFields.length == 1
					? gcm.decodeSingle(elemFields[0], resultSet, 1)
					: gcm.getPBinder().decodeAbstract(this, null));
		} catch (Exception e) {
			throw new NoSuchElementException(
					"Impossible to decode to a PName: " + e.getMessage());
		}
	}

	public void remove() throws UnsupportedOperationException {
		throw new UnsupportedOperationException();
	}

	public void close() throws PException {
		if (!prefetching)  {
			hasNext = false;
			isForw = true;
			try {
				resultSet.close();
			} catch (SQLException e) {
				throw new PExceptionIO(e);
			}
		}
	}
}
