/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.generator;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.mapper.rdb.metainfo.RdbJoin;

import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class RdbGenJoin {

	public RdbGenTable mainTable = null;
	public RdbGenTable table = null;
	public int joinIdx = 0;

	/**
	 * The list of columns used to join with the reference table.
	 * null for the reference table. These columns belongs to one of the other
	 * tables used in this mapping.
	 */
	public List joinColumnsInMain = null;

	/**
	 * Along with this list, we define the position the column of this table
	 * with which these external columns join.
	 */
	public List joinColumnsInExt = null;

	public int getJoinIdx() {
		return joinIdx;
	}

	public List getJoinColumnsInMain() {
		return joinColumnsInMain;
	}

	public List getJoinColumnsInExt() {
		return joinColumnsInExt;
	}

	public RdbGenTable getMainTable() {
		return mainTable;
	}

	public RdbGenTable getTable() {
		return table;
	}

	public RdbGenJoin(RdbGenTable mainTable,
					  RdbGenTable extTable,
					  RdbJoin j,
					  int idx) throws PException {
		this.joinIdx = idx;
		//System.out.println("Define a join:");
		this.table = extTable;
		this.mainTable = mainTable;
		//Define the join between the main extTable and the slave extTable
		List pcns = j.getPTJoinColumnNames();
		List ecns = j.getETJoinColumnNames();
		joinColumnsInMain = new ArrayList(pcns.size());
		joinColumnsInExt = new ArrayList(pcns.size());
		for (int i = 0; i < pcns.size(); i++) {
			String pcn = (String) pcns.get(i);
			String ecn = (String) ecns.get(i);
			//System.out.println("between: " + mainTable.tableName + "." + pcn + " and " + extTable.tableName + "." + ecn);
			RdbGenColumn pjcol = mainTable.getColumn(pcn);
			if (pjcol == null) {
				throw new PException("In the join between tables "
                        + mainTable.tableName + " and " + extTable.tableName + ", " +
                        "the column '" + pcn + "' was not found in extTable "
                        + mainTable.tableName);
			}
			joinColumnsInMain.add(pjcol);
			RdbGenColumn ejcol = extTable.getColumn(ecn);
			if (ejcol == null) {
				ejcol = new RdbGenColumn();
				ejcol.columnName = ecn;
				ejcol.joinCol = pjcol;
				ejcol.columnType = pjcol.columnType;
				ejcol.columnSqlType = pjcol.columnSqlType;
				ejcol.table = extTable;
				ejcol.fieldName = pjcol.fieldName;
				ejcol.columnNotNull = pjcol.columnNotNull;
				ejcol.joins = null;
				ejcol.pes = null;
			}
			joinColumnsInExt.add(ejcol);
			extTable.columns.add(ejcol);
		}
	}

}
