/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.lib;

import org.objectweb.jorm.lib.MapperJCA;
import org.objectweb.jorm.api.JormConfigurator;
import org.objectweb.jorm.mapper.rdb.adapter.api.RdbAdapter;
import org.objectweb.jorm.mapper.rdb.adapter.RdbAdapterFactory;
import org.objectweb.jorm.api.PException;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * This mapper supports JDBC connection management through JCA.
 * @author	P. Dechamboux
 */
public class MapperJCA_JDBC extends MapperJCA implements PMapperRdb {
	private RdbAdapter adapter = null;

	public MapperJCA_JDBC() throws PException {
		super();
	}

	public MapperJCA_JDBC(JormConfigurator jc) {
		super(jc);
	}

	/**
	 * @return the RdbAdapter instance associated to this mapper.
	 */
	public RdbAdapter getRdbAdapter() {
		if (adapter == null) {
			try {
				String dbn;
				if (getMapperName().indexOf(".") == -1)
					dbn = RdbAdapterFactory.DATABASE_NAME_JDBC;
				else
					dbn = getMapperName().substring(getMapperName().indexOf(".") + 1);
					adapter = RdbAdapterFactory.getTypeConverter(dbn);
			} catch (Exception e) {
				if (logger != null) {
					logger.log(BasicLevel.ERROR, "Impossible to find a compatible RdbAdapter:", e);
				} else {
					e.printStackTrace();
				}
			}
		}
		return adapter;
	}
}
