/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.lib;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.PExceptionIO;
import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.perseus.persistence.api.ConnectionHolder;

import java.sql.Connection;

/**
 * Defines a connection wrapper for all kind of connection that can be used
 * with the RDB mapper.
 * @author	P. Dechamboux
 */
public class RdbConnectionWrapper {
	/**
	 * Narrows a connection requested to a mapper into an SQL connection.
	 * @param conn	A mapper connection.
	 * @return An SQL connection.
	 * @throws PException Thrown when narrowing is impossible.
	 */
	public static Connection narrow2SQL(Object conn) throws PException {
		if (conn == null) {
			throw new PExceptionProtocol("Impossible to narrow a null connection");
		}
		if (conn instanceof Connection)
			return (Connection) conn;
		if (conn instanceof ConnectionHolder) {
			try {
				return (Connection) ((org.objectweb.perseus.persistence.api.ConnectionHolder) conn).getCHConnectionForWrite();
			} catch (org.objectweb.perseus.persistence.api.PersistenceException e) {
				throw new PExceptionIO(e, "Impossible to fetch a connection to access to the RDB.");
			}
		}
		throw new PExceptionProtocol("Unknow type of connection to be narrowed to a SQL connection.");
	}
}
