/**
 * Speedo: an implementation of JDO compliant personality on top of JORM generic
 * I/O sub-system.
 * Copyright (C) 2001-2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *
 * Contact: speedo@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.lib;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;

import org.objectweb.medor.api.MedorException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.tuple.api.Tuple;
import org.objectweb.medor.tuple.api.TupleCollection;

/**
 * @author Y.Bersihand
 */
public class RdbIntermediaryTuple implements Tuple {

	private int[] associationTable;
	private Tuple delegatePbTuple = null;
	
	public RdbIntermediaryTuple(int[] associationTable, Tuple delegatePbTuple) {
		this.associationTable = associationTable;
		this.delegatePbTuple = delegatePbTuple;
	}
	
	public int getSize() {
		return associationTable.length;
	}

	public Operand[] toOperandArray() {
		return null;
	}

	public boolean getBoolean(int index) throws MedorException {
		return delegatePbTuple.getBoolean(associationTable[index-1] + 1);
	}

	public byte getByte(int index) throws MedorException {
		return delegatePbTuple.getByte(associationTable[index-1] + 1);
	}

	public byte[] getByteArray(int index) throws MedorException {
		return delegatePbTuple.getByteArray(associationTable[index-1] + 1);
	}

	
	public char getChar(int index) throws MedorException {
		return delegatePbTuple.getChar(associationTable[index-1] + 1);
	}

	public char[] getCharArray(int index) throws MedorException {
		return delegatePbTuple.getCharArray(associationTable[index-1] + 1);
	}

	public Date getDate(int index) throws MedorException {
		return delegatePbTuple.getDate(associationTable[index-1] + 1);
	}

	public double getDouble(int index) throws MedorException {
		return delegatePbTuple.getDouble(associationTable[index-1] + 1);
	}

	public float getFloat(int index) throws MedorException {
		return delegatePbTuple.getFloat(associationTable[index-1] + 1);
	}

	public int getInt(int index) throws MedorException {
		return delegatePbTuple.getInt(associationTable[index-1] + 1);
	}

	public Operand getLikeOperand(int index) throws MedorException {
		return null;
	}

	public long getLong(int index) throws MedorException {
		return delegatePbTuple.getLong(associationTable[index-1] + 1);
	}

	public Object getObject(int index) throws MedorException {
		return delegatePbTuple.getObject(associationTable[index-1] + 1);
	}

	public short getShort(int index) throws MedorException {
		return delegatePbTuple.getShort(associationTable[index-1] + 1);
	}

	public BigDecimal getBigDecimal(int index) throws MedorException {
		return delegatePbTuple.getBigDecimal(associationTable[index-1] + 1);
	}

	public BigInteger getBigInteger(int index) throws MedorException {
		return delegatePbTuple.getBigInteger(associationTable[index-1] + 1);
	}

	public String getString(int index) throws MedorException {
		return delegatePbTuple.getString(associationTable[index-1] + 1);
	}


	public TupleCollection getTupleCollection(int index) throws MedorException {
		// TODO Auto-generated method stub
		return null;
	}

	public boolean isDefined(int index) {
		return delegatePbTuple.isDefined(associationTable[index-1] + 1);
	}

}
