/**
 * Copyright (C) 2003-2004
 * - France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors: Olivier Lobry (olivier.lobry@francetelecom.com)
 * Date: 13 sept. 2004
 * Time: 14:43:03
 */

package org.objectweb.jorm.mapper.rdb.lib;

import org.objectweb.jorm.api.PException;

/**
 * This interface is supposed to be implemented by (generated) polymorphic classes.
 * It permits to append the filter expession at runtime when creating the queries representing 
 * full-extents of polymorphic classes. Filters are defined on a statement basis: a query
 * can be defined as an union of select/from/where statements, each may having filters to be added.
 * Thus statements are named so that we can add the correct filtering expression to the right statement.
 */
public interface RdbPPolymorphicClass {
    /**
     * This method is called when creating queries. 
     * It append the filtering expression corresponding to a statement of the query
     * representing the full-extent of the (polymorphic) (generated) class
     * The name of the statement to which the filtering expression is to be added
     * is specified by the given name, so that the right filtering expression is added. 
     * The string buffer given in parameter should already contain an SQL 
     * expression of the form:
     * 'select ... from ... where' or 
     * 'select ... from ... where ... and' 
     * @param stmtName the name of the statement in the query definition
     * @param sb the string buffer to which adding the filtering expression.
     */
    void appendExtentFilters(String stmtName, StringBuffer sb);
    
    /**
	 * Returns the primary key of the class as a String of type "x1, x2"
	 * where x1 and x2 compose the primary key.
	 * @return
	 */
	String getPNameFields();
	
	/**
	 * Returns the query computed in the pcm.
	 * If withPrefetch is true, returns the prefetchExtentQuery
	 * else, returns extentQuery.
	 */
	String getExtentQuery(boolean withPrefetch) throws PException;
}
