/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import java.util.Collection;

/**
 * A Mapping object contains mapping structures obtained by applying a set of
 * mapping rules whose syntax and semantics depend of a particular mapper.
 *
 * Mapping rules define the way class instances will be stored on a particular
 * type of persistent store and how they will be read and write from/to the
 * persistent store.
 *
 */
public interface Mapping extends MetaObject {
	/**
	 * Returns the name of the mapper.
	 * @return	 the mapper name.
	 */
	String getMapperName();

	/**
	 * Sets the mapper name.
	 * @param mapperName   the mapper name.
	 */
	void setMapperName(String mapperName);

	/**
	 * Returns the mapping structure of the class.
	 * @return	 a ClassMapping object.
	 */
	ClassMapping getClassMapping();

	/**
	 * Sets the mapping structure of the class.
	 * @param classMapping	a ClassMapping object.
	 */
	void setClassMapping(ClassMapping classMapping);

	/**
	 * Returns the GenClassMapping object of a GenClass.
	 * @param  genclassid   a GenClass identifier.
	 * @return a GenClassMapping object.
	 */
	GenClassMapping getGenClassMapping(String genclassid);

	/**
	 * Returns a collection of GenClassMapping objects.
	 * @return	 a collection.
	 */
	Collection getGenClassMappings();

	/**
	 * Adds a GenClassMapping object.
	 * @param  genClassId       a GenClass identifier,
	 *         genClassMapping	a GenClassMapping object.
	 */
	void addGenClassMapping(String genClassId,
							GenClassMapping genClassMapping);
    /**
     * Create a class mapping
     * @param ruleName
     * @return
     */ 
    ClassMapping createClassMapping(String ruleName);

}
