/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.metainfo.api;

import org.objectweb.jorm.metainfo.api.ClassMapping;
import org.objectweb.jorm.metainfo.api.PrimitiveElementMapping;

import java.io.PrintStream;
import java.util.Iterator;

/**
 * This abstract class must be extends for each mapping. The aim is to print
 * the meta objects ValueMapping and ClassMapping.
 *
 * @author S.Chassande-Barrioz
 */
public abstract class MappingPrinter {

	public final static String TAB = "    ";

	/**
	 * It retrieves true if the MappingPrinter is able to print the
	 * MappingStructure specified in parameter.
	 * This default implementation return always false.
	 */
	public boolean canPrint(MappingStructure pem) {
		return false;
	}

	public abstract void print(String p, PrimitiveElementMapping pem, PrintStream out);

	public void print(String p, ClassMapping cm, PrintStream out) {
		NameDef nd = (NameDef) cm.getIdentifierMapping().getLinkedMO();
		out.println(p + "The name def '"
					+ nd.getName()
					+ "' is used for the class");
		Iterator it = cm.getReferenceMappings().iterator();
		while (it.hasNext()) {
			nd = (NameDef) ((ReferenceMapping) it.next()).getLinkedMO();
			out.println(p + "The name def '"
						+ nd.getName()
						+ "' is used for the reference '"
						+ ((TypedElement) nd.getParent()).getName() + "'");
		}
		it = cm.getParentClassMappings().iterator();
		if (!it.hasNext()) {
			out.println(p + "No ParentClassMapping");
		} else {
			while (it.hasNext()) {
				print(p + TAB, (ParentClassMapping) it.next(), out);
			}
		}
	}

	public void print(String p, ParentClassMapping pcm, PrintStream out) {
		out.println(p + "Super class: " + pcm.getMOClass().getFQName()
			+ ", RuleName: " + pcm.getRuleName());
	}

	public void print(String p, GenClassMapping gcm, PrintStream out) {
		NameDef nd = (NameDef) gcm.getIdentifierMapping().getLinkedMO();
		out.println(p + "The name def '"
					+ nd.getName()
					+ "' is used for the generic class '"
					+ ((GenClassRef) gcm.getLinkedMO()).getGenClassId() + "'");

		ReferenceMapping rm = gcm.getReferenceMapping();
		if (rm != null) {
			nd = (NameDef) rm.getLinkedMO();
			out.println(p + "The name def '"
						+ nd.getName()
						+ "' is used for the element of the generic class '"
						+ ((GenClassRef) gcm.getLinkedMO()).getGenClassId() + "'");
		}
	}
}
