/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import java.util.Iterator;

/**
 * A PrimitiveElement is a field with a primitive type. Type can be
 * boolean | byte | char | short | int | long | float | double |
 * string | serialized| date | time | timestamp
 * A primitive type can not be extended.
 * @author	X. Spengler
 */
public interface PrimitiveElement extends TypedElement {

	int CONSTANT_PERSISTENT = 2;
	int CONSTANT_NON_PERSISTENT = 3;
	int VARIABLE_PERSISTENT = 1;

	/**
	 * Allows to know if the current Field is a scalar field or not.
	 *
	 * @return	true, if the Field is scalar, else false, if the Field is not
	 *          scalar
	 */
	boolean isScalar();

	/**
	 * Returns the size of the field in case of string, serialized, arrays,
	 * bigdecimal, etc
	 * @return the size for this type
	 */
	int getSize();

	int getScale();

	/**
	 * Gets the status wrt constance and persistence.
	 * @see this.setStatus()
	 */
	int getStatus();

	/**
	 * Assigns the status indicating if the primitive element is one of:
	 * <ul><li>variable and persistent (classical case)</li>
	 * <li>constant and persistent</li>
	 * <li>constant and not persistent</li>
	 * </ul>
	 */
	void setStatus(int status);

	/**
	 * @return true if the field is constant
	 */
	boolean isConstant();

	/**
	 * @return true if the field is persistent
	 */
	boolean isPersistent();

	/**
	 * Indicate if the primitive element is auto calculated. In case of a
	 * CompositeName, an auto calculated field means that the value is
	 * calculated by an external tool. In case of a class, an auto calculated
	 * field means that the value is calculated by the data support (auto
	 * increment value for instance).
	 */
	boolean isAutoCalculated();

	/**
	 *
	 * @see this.isAutoCalculated()
	 */
	void setIsAutoCalculated(boolean autocalculated);
}
