/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.lib;

import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.PrimitiveElement;
import org.objectweb.jorm.type.api.PType;

/**
 * The BasicPrimitiveElement object is used to define fields which
 * are primitive types. This object is defined by its name, its type,
 * its parent, its size (if used) and a list of mappings for the field.
 * @author	X. Spengler
 */
public class BasicPrimitiveElement
    extends BasicTypedElement
    implements PrimitiveElement {


	boolean isAutoCalculated = false;

	int status = VARIABLE_PERSISTENT;

	/**
	 * The size of the field
	 */
	private int size = PType.NOSIZE;
	private int scale = PType.NOSIZE;


	/**
	 * Builds a new PrimitiveElement object.
	 * This object is mainly defined by its name, its type and its parent.
	 *
	 * @param name	the name of the primitive field
	 * @param type	the type of the field (PType object)
	 * @param parent	the parent of the current object
	 */
	public BasicPrimitiveElement(String name,
								 PType type,
								 int size,
								 int scale,
								 MetaObject parent) {
		super(name, type, parent);
		this.size = size;
		this.scale = scale;

	}

	///////////////////////////////////////////////////////////////////
	//                      from PrimitiveElement interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Returns the size of the field in case of string, serialized, arrays, etc
	 * @return the size for this type
	 */
	public int getSize() {
		return size;
	}

	public int getScale() {
		return scale;
	}

	/**
	 * Allows to know if the current Field is a scalar field or not.
	 *
	 * @return	true, if the Field is scalar, else false, if the Field is not
	 *          scalar
	 */
	public boolean isScalar() {
		// TBD return false for the moment
		return false;
	}

	public boolean isAutoCalculated() {
		return isAutoCalculated;
	}

	public void setIsAutoCalculated(boolean autocalculated) {
		isAutoCalculated = autocalculated;
	}

	public int getStatus() {
		return status;
	}

	public void setStatus(int status) {
		this.status = status;
	}

	public boolean isConstant() {
		return status == CONSTANT_NON_PERSISTENT
				|| status == CONSTANT_PERSISTENT;
	}

	public boolean isPersistent() {
		return status == CONSTANT_PERSISTENT || status == VARIABLE_PERSISTENT;
	}
}
