/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.jorm.naming.api;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.type.api.PType;

import java.util.Map;

/**
 *
 * @author S.Chassande-Barrioz
 */
public interface KeyFilteredNamingContext extends PNamingContext {

	/**
	 * Export a new persistent class into this PNamingContext
	 * @param binder is the PBinder instance of the persistent class
	 * @param key is the key value permitting to identify the persistent class
	 * @throws PException if the class is already exported in this
	 * PNamingContext.
	 */
	void exportClass(PBinder binder, Object key) throws PException;

	/**
	 * Unexport a persistent class from this PNamingContext
	 * @param key is the key value permitting to identify the persistent class
	 * @throws PException if the persistent class is not managed by this
	 * PNamingContext.
	 */
	void unexportClass(Object key) throws PException;

	/**
	 * @param key is the persistent class identifier
	 * @return the Pbinder instance corresponding a persistent class
	 */
	PBinder lookup(Object key);

	/**
	 * @return an unmodifiable map representing the associations between
	 * a persistent class identifiers (key) and the binder of the persistent
	 * class.
	 */
	Map entries();

	/**
	 * Evaluate the Expression/filter on a PNameGetter
	 * @param png is a PNameGetter permitting to fill the expression parameters
	 * @return value of the expression. This value should be a key value of a
	 * persistent class.
	 */
	Object evaluate(Object png, Object ctx) throws PException;

	void setExpressionType(PType type);

	PType getExpressionType();

}
