/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.util.api;

import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.LoggerFactory;

/**
 * The interface Loggable must be implemented by all objects
 * which want to log something.
 * @author	P. Dechamboux
 */
public interface Loggable {
	/**
	 * Returns a logger to an component that wants to log things.
	 */
	Logger getLogger();

	/**
	 * Returns a logger factory that allows the creation of new loggers.
	 */
	LoggerFactory getLoggerFactory();

	/**
	 * Assigns a logger to an component that wants to log things.
	 *
	 * @param logger	the logger object
	 */
	void setLogger(Logger logger);

	/**
	 * Assigns a logger factory that allows the creation of new loggers.
	 *
	 * @param loggerfactory	the LoggerFactory object to obtain new loggers
	 */
	void setLoggerFactory(LoggerFactory loggerfactory);

}
