/**
 * Copyright (C) 2003-2004
 * - France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors: Olivier Lobry (olivier.lobry@francetelecom.com)
 * Date: 27 sept. 2004
 * Time: 17:41:59
 */

package org.objectweb.jorm.mapper.rdb.inheritance;

import java.util.ArrayList;
import java.util.Iterator;

import org.objectweb.jorm.api.PClassMapping;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.facility.naming.generator.LongGenMgr;
import org.objectweb.jorm.facility.naming.generator.rdb.LongGenIncrMapping;
import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.pobject.inheritance.extent.AnimalIdBinder;
import org.objectweb.jorm.runtime.TestRuntimeHelper;

/**
 * Test that the view representing the extents are correctly
 * generated. By extents, we mean here the collection of all
 * instances belonging to a given class or its sub-classes.
 */
public class TestRdbViewExtent extends TestRuntimeHelper {
    private final static String LOGGER_NAME
             = "test.org.objectweb.jorm.mapper.rdb.inheritance";
    private final static String CNPREFIX
             = "org.objectweb.jorm.pobject.inheritance.extent.";
    private ArrayList animals = new ArrayList();

    static LongGenMgr longgenmgr;

    public TestRdbViewExtent(String testName) throws Exception {
        super(testName);
    }

    protected void setUp() throws Exception {
        super.setUp();
        synchronized(TestRdbViewExtent.class) {
            if (longgenmgr == null) {
                longgenmgr = new LongGenIncrMapping();
                longgenmgr.init(mapper, PClassMapping.CREATE_STRUCTURE_IF_NEEDED);
            }
        }
    }

    protected String getLoggerName() {
        return LOGGER_NAME;
    }
    protected PBinder getBinder(String className) throws Exception {
        AnimalIdBinder binder = new AnimalIdBinder();
        binder.setACFLid(longgenmgr.getLongGen(className));
        return binder;
     }

    private void createAnimal(Animal a) throws PException {
        String className;
        if (a instanceof Kangaroo) {
            className = CNPREFIX + "Kangaroo";
        } else if (a instanceof Koala) {
            className = CNPREFIX + "Koala";
        } else if (a instanceof Eagle) {
            className = CNPREFIX + "Eagle";
        } else if (a instanceof Pigeon) {
            className = CNPREFIX + "Pigeon";
        } else {
            throw new PException("Unknown persistance class");
        }
        if (!performIO(className, a, a, a, false)) {
            throw new PException("cannot create animal");
        }
    }

    public void testView() throws Exception {
        animals.add(new Kangaroo(true, 120, 40, (float) 6.5));
        animals.add(new Kangaroo(false, 132, 40, (float) 6.5));
        animals.add(new Koala(true, 78, 30, 20));
        animals.add(new Koala(false, 70, 30, 20));
        animals.add(new Eagle(true, 80, "Italy", 100));
        animals.add(new Eagle(false, 85, "France", 100));
        animals.add(new Pigeon(true, 32, "Belgique", 123));
        animals.add(new Pigeon(false, 31, "France", 123));


        for (Iterator it = animals.iterator(); it.hasNext();) {
            Animal animal = (Animal) it.next();
            createAnimal(animal);
        }
     }


}
