/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.lib;

import junit.framework.TestCase;

import java.io.InputStream;
import java.io.ObjectInputStream;
import java.sql.Blob;

/**
 * Basic code for testing BLOBs.
 * @author S. Chassande-Barrioz
 */
public abstract class TestRdbBlob extends TestCase {

	public TestRdbBlob(String testName) {
		super(testName);
	}

	protected Blob blob = null;

	protected BlobVerifier verifier = null;

	protected abstract void setUp();

	protected abstract void tearDown();

	// Test the access by the blob interface
	public void testGetBytes() {
		try {
			assertTrue("blob.length", verifier.isSize(blob.length()));
			byte[] data = blob.getBytes(0, (int) blob.length());
			for (int i = 0; i < data.length; i++) {
				println("data[" + i + "]=" + data[i]);
				assertTrue("invalid value at " + i + " position",
					verifier.valid(data[i], i));
			}
		}
		catch (Exception e) {
			fail(e.getMessage());

		}
	}

	public void testRead() {
		try {
			// Test the access by an InputStream
			InputStream is = blob.getBinaryStream();
			assertTrue("blob.getBinaryStream() is null", is != null);
			for (long i = 0; i < blob.length(); i++) {
				byte aByte = (byte) is.read();
				println("read [" + i + "]=" + aByte);
				assertTrue("invalid value at " + i + " position",
					verifier.valid(aByte, i));
			}
		}
		catch (Exception e) {
			fail(e.getMessage());
		}
	}

	// Test the access by an InputStream
	public void testSkip() {
		try {
			InputStream is = blob.getBinaryStream();
			assertTrue("blob.getBinaryStream() is null", is != null);
			is.skip(blob.length() / 3);
			for (long i = blob.length() / 3; i < blob.length(); i++) {
				byte aByte = (byte) is.read();
				println("sk+read [" + i + "]=" + aByte);
				assertTrue("invalid value at the position " + i,
					verifier.valid(aByte, i));
			}
		}
		catch (Exception e) {
			fail(e.getMessage());
		}
	}

	// Test the access by an ObjectInputStream
	public void testRebuildObject() {
		try {
			ObjectInputStream ois =
				new ObjectInputStream(blob.getBinaryStream());
			assertTrue("ObjectInputStream is null", ois != null);
			Object o = ois.readObject();
			assertTrue("Deserialized object does not match",
				verifier.isEquals(o));
		}
		catch (Exception e) {
			fail(e.getMessage());
		}
	}

	private void println(String msg) {
		//System.out.println(msg);
	}
}
