/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.lib;

import junit.framework.Test;
import junit.framework.TestSuite;
import junit.textui.TestRunner;

import java.io.Serializable;

/**
 * @author	<A HREF="mailto:sebastien.chassande@inrialpes.fr><b>
 *			Sebastien Chassande-Barrioz
 *			</b></A>
 */
public class TestRdbBlobSmallObject extends TestRdbBlob {

	public TestRdbBlobSmallObject() {
		super("TestRdbBlobSmallObject");
	}

	public TestRdbBlobSmallObject(String name) {
		super(name);
	}

	public void setUp() {
		try {
			verifier = new StringBlobVerifier();
			blob = new RdbBlob(verifier.getObject(), 27);
			assertNotNull("Blob is null", blob);
		}
		catch (Exception e) {
			fail(e.getMessage());
		}
	}

	protected void tearDown() {
		blob = null;

	}

	public static void main(String args[]) {
		TestRunner.run(suite());
	}

	public static Test suite() {
		return new TestSuite(TestRdbBlobSmallObject.class);
	}
}

class StringBlobVerifier implements BlobVerifier {
	private static final String object = "azertyuiop1234567890";
	private static final byte[] tab = {-84, -19, 0, 5, 116, 0, 20, 97, 122,
									   101, 114, 116, 121, 117, 105, 111, 112,
									   49, 50, 51, 52, 53, 54, 55, 56, 57, 48};

	public boolean valid(byte aByte, long pos) {
		return pos < tab.length && aByte == tab[(int) pos];
	}

	public boolean isSize(long size) {
		return size == tab.length;
	}

	public boolean isEquals(Object o) {
		return object.equals(o);
	}

	public Serializable getObject() {
		return object;
	}

	public String toString() {
		return "size=" + tab.length;
	}
}
