/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.runtime.basictype;

import org.objectweb.jorm.runtime.TestRuntimeHelper;
import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.facility.naming.basidir.BasidBinder;
import org.objectweb.jorm.api.PClassMapping;
import org.objectweb.jorm.api.PException;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class TestAllTypes extends TestRuntimeHelper {

    private final static String LOGGER_NAME
            = "test.org.objectweb.jorm.basictype.alltypes";

    private final static String CN_ALL_TYPES = "org.objectweb.jorm.pobject.basictype.AllTypes";

    public TestAllTypes(String name) throws Exception {
        super(name);
    }

    protected String getLoggerName() {
        return LOGGER_NAME;
    }

    protected PBinder getBinder(String className) throws Exception {
        try {
            return new BasidBinder(mapper,
                    "org.objectweb.jorm.runtime.basictype.TestBasicType",
                    PClassMapping.CLEANUP_REMOVEALL);
        } catch (PException e) {
            Exception current = e;
            while (current instanceof PException
                    && ((PException) current).getNestedException() != null) {
                current = ((PException) current).getNestedException();
            }
            throw current;
        }
    }

    public void test1() {
        AllTypesAcc acc1 = new AllTypesAcc();
        acc1.booleanValue1 = true;
        acc1.booleanValue2 = false;
        acc1.obooleanValue1 = Boolean.TRUE;
        acc1.obooleanValue2 = Boolean.FALSE;
        acc1.byteValue1 = 1;
        acc1.byteValue2 = 2;
        acc1.obyteValue1 = new Byte((byte) 1);
        acc1.obyteValue2 = new Byte((byte) 2);
        acc1.charValue1 = 'a';
        acc1.charValue2 = 'b';
        acc1.ocharValue1 = new Character('a');
        acc1.ocharValue2 = new Character('b');
        acc1.shortValue1 = 1;
        acc1.shortValue2 = 2;
        acc1.oshortValue1 = new Short((short) 1);
        acc1.oshortValue2 = new Short((short) 2);
        acc1.intValue1 = 1;
        acc1.intValue2 = 2;
        acc1.ointValue1 = new Integer(1);
        acc1.ointValue2 = new Integer(2);
        acc1.longValue1 = 1;
        acc1.longValue2 = 2;
        acc1.olongValue1 = new Long(1);
        acc1.olongValue2 = new Long(2);
        acc1.floatValue1 = 1;
        acc1.floatValue2 = 2;
        acc1.ofloatValue1 = new Float(1);
        acc1.ofloatValue2 = new Float(2);
        acc1.doubleValue1 = 1;
        acc1.doubleValue2 = 2;
        acc1.odoubleValue1 = new Double(1);
        acc1.odoubleValue2 = new Double(2);
        acc1.chararrayValue1 = new char[]{'a', 'z', 'e', 'r', 't', 'y'};
        acc1.chararrayValue2 = new char[]{'q', 's', 'd', 'f', 'g', 'h'};
        acc1.bytearrayValue1 = "azerty".getBytes();
        acc1.bytearrayValue2 = "qsdfgh".getBytes();
        acc1.stringValue1 = "azerty";
        acc1.stringValue2 = "qsdfgh";
        acc1.dateValue1 = getTime();
        try {
            Thread.sleep(1000);
        } catch (InterruptedException e) {
        }
        acc1.dateValue2 = getTime();

        AllTypesAcc acc2 = new AllTypesAcc();
        performIO(CN_ALL_TYPES, acc1, acc2);
        assertEquals("Bad booleanValue1", acc1.booleanValue1, acc2.booleanValue1);
        assertEquals("Bad booleanValue2", acc1.booleanValue2, acc2.booleanValue2);
        assertEquals("Bad obooleanValue1", acc1.obooleanValue1, acc2.obooleanValue1);
        assertEquals("Bad obooleanValue2", acc1.obooleanValue2, acc2.obooleanValue2);

        assertEquals("Bad byteValue1", acc1.byteValue1, acc2.byteValue1);
        assertEquals("Bad byteValue1", acc1.byteValue1, acc2.byteValue1);
        assertEquals("Bad obyteValue1", acc1.obyteValue1, acc2.obyteValue1);
        assertEquals("Bad obyteValue1", acc1.obyteValue1, acc2.obyteValue1);

        assertEquals("Bad charValue1", acc1.charValue1, acc2.charValue1);
        assertEquals("Bad charValue2", acc1.charValue2, acc2.charValue2);
        assertEquals("Bad ocharValue1", acc1.ocharValue1, acc2.ocharValue1);
        assertEquals("Bad ocharValue2", acc1.ocharValue2, acc2.ocharValue2);

        assertEquals("Bad shortValue1", acc1.shortValue1, acc2.shortValue1);
        assertEquals("Bad shortValue2", acc1.shortValue2, acc2.shortValue2);
        assertEquals("Bad oshortValue1", acc1.oshortValue1, acc2.oshortValue1);
        assertEquals("Bad oshortValue2", acc1.oshortValue2, acc2.oshortValue2);

        assertEquals("Bad intValue1", acc1.intValue1, acc2.intValue1);
        assertEquals("Bad intValue2", acc1.intValue2, acc2.intValue2);
        assertEquals("Bad ointValue1", acc1.ointValue1, acc2.ointValue1);
        assertEquals("Bad ointValue2", acc1.ointValue2, acc2.ointValue2);

        assertEquals("Bad longValue1", acc1.longValue1, acc2.longValue1);
        assertEquals("Bad longValue2", acc1.longValue2, acc2.longValue2);
        assertEquals("Bad olongValue1", acc1.olongValue1, acc2.olongValue1);
        assertEquals("Bad olongValue2", acc1.olongValue2, acc2.olongValue2);

        assertEquals("Bad floatValue1", acc1.floatValue1, acc2.floatValue1, (float) 0);
        assertEquals("Bad floatValue2", acc1.floatValue2, acc2.floatValue2, (float) 0);
        assertEquals("Bad ofloatValue1", acc1.ofloatValue1, acc2.ofloatValue1);
        assertEquals("Bad ofloatValue2", acc1.ofloatValue2, acc2.ofloatValue2);

        assertEquals("Bad doubleValue1", acc1.doubleValue1, acc2.doubleValue1, (double) 0);
        assertEquals("Bad doubleValue2", acc1.doubleValue2, acc2.doubleValue2, (double) 0);
        assertEquals("Bad odoubleValue1", acc1.odoubleValue1, acc2.odoubleValue1);
        assertEquals("Bad odoubleValue2", acc1.odoubleValue2, acc2.odoubleValue2);

        assertEqual("chararrayValue1 ", acc1.chararrayValue1, acc2.chararrayValue1);
        assertEqual("chararrayValue2 ", acc1.chararrayValue2, acc2.chararrayValue2);
        assertEqual("bytearrayValue1 ", acc1.bytearrayValue1, acc2.bytearrayValue1);
        assertEqual("bytearrayValue2 ", acc1.bytearrayValue2, acc2.bytearrayValue2);

        assertEquals("Bad stringValue1", acc1.stringValue1, acc2.stringValue1);
        assertEquals("Bad stringValue1", acc1.stringValue2, acc2.stringValue2);

        if (acc1.dateValue1 == null) {
            assertNull("dateValue1 must be null", acc2.dateValue1);
        } else {
            assertNotNull("dateValue1 must not be null", acc2.dateValue1);
            assertEquals("Bad dateValue1",
                    acc1.dateValue1.getTime(), acc2.dateValue1.getTime());
        }
        if (acc1.dateValue2 == null) {
            assertNull("dateValue2 must be null", acc2.dateValue2);
        } else {
            assertNotNull("dateValue2 must not be null", acc2.dateValue2);
            assertEquals("Bad dateValue2",
                    acc1.dateValue2.getTime(), acc2.dateValue2.getTime());
        }
    }
}
