/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.runtime.gcbasictypeelem;

import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.pobject.gcbasictypeelem.BooleanSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.ByteSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.CharSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.DoubleSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.DateSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.FloatSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.IntSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.LongSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.ObooleanSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.ObyteSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OcharSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OdoubleSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OfloatSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OintSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OlongSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.OshortSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.ShortSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.StringSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.SerializedSetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.BytearraySetAccessor;
import org.objectweb.jorm.pobject.gcbasictypeelem.ChararraySetAccessor;
import org.objectweb.jorm.naming.api.PName;
import junit.framework.Assert;

/**
 * @author P. Dechamboux
 */
public class GcRefAccessor implements
        BooleanSetAccessor,
        ObooleanSetAccessor,
        ByteSetAccessor,
        ObyteSetAccessor,
        CharSetAccessor,
        OcharSetAccessor,
        ShortSetAccessor,
        OshortSetAccessor,
        IntSetAccessor,
        OintSetAccessor,
        LongSetAccessor,
        OlongSetAccessor,
        FloatSetAccessor,
        OfloatSetAccessor,
        DoubleSetAccessor,
        OdoubleSetAccessor,
        StringSetAccessor,
        DateSetAccessor,
        SerializedSetAccessor,
        BytearraySetAccessor,
        ChararraySetAccessor,
        PAccessor {
    private PName gcRef;

    public GcRefAccessor(PName gcRef) {
        this.gcRef = gcRef;
    }

    //Accessors to the mygc field
    public void paSetMygc(PName val, Object connection) throws PException {
        gcRef = val;
    }

    public PName paGetMygc(Object connection) throws PException {
        return gcRef;
    }

    public Object getMemoryInstance() {
        return this;
    }

    public boolean equals(Object obj) {
        Assert.assertTrue("Wrong object class: should be a GcRefAccessor", obj instanceof GcRefAccessor);
        Assert.assertEquals("Wrong refernce", gcRef, ((GcRefAccessor) obj).gcRef);
        return true;
    }
}
