/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.runtime.multitable;

import org.objectweb.jorm.pobject.multitable.ClassRef_SN_MTAccessor;
import org.objectweb.jorm.pobject.multitable.ClassRef_CN_MTAccessor;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.api.PException;
import junit.framework.Assert;

/**
 * @author	S. Chassandes-Barrioz
 */
public class ClassRef_MT
    implements ClassRef_SN_MTAccessor,
    ClassRef_CN_MTAccessor {

    public PName c = null;
    public PName d = null;

    public ClassRef_MT() {
    }

    public ClassRef_MT(PName c, PName d) {
        this.c = c;
        this.d = d;
    }
    public String toString() {
        return "ClassRef_MT(" + c + ", " + d + ")";
    }

    /**
     * (obj instanceof ClassRef_MT)
     *      && (cr = ((ClassRef_MT) obj)) != null
     *      && (c == null ? cr.c == null : c.equals(cr.c))
     *      && (d == null ? cr.d == null : d.equals(cr.d));
     * @param obj
     * @return
     */
    public boolean equals(Object obj) {
        Assert.assertNotNull("Null value", obj);
        Assert.assertEquals("Bad class", ClassRef_MT.class, obj.getClass());
        ClassRef_MT cr = (ClassRef_MT) obj;
        Assert.assertEquals("Bad c value", c, cr.c);
        Assert.assertEquals("Bad d value", d, cr.d);
        return true;
    }

    //Accessors to the d field
    public void paSetD(PName val, Object connection) throws PException {
        d = val;
    }

    public PName paGetD(Object connection) throws PException {
        return d;
    }

    //Accessors to the c field
    public void paSetC(PName val, Object connection) throws PException {
        c = val;
    }

    public PName paGetC(Object connection) throws PException {
        return c;
    }

    public Object getMemoryInstance() {
        return this;
    }
}
