/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.runtime.namedef;

import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PException;

import org.objectweb.jorm.pobject.singlename.ASingleByteIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleCharIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleShortIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleIntIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleLongIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleObyteIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleOcharIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleOshortIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleOintIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleOlongIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleStringIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleDateIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleBytearrayIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleChararrayIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleBigDecimalIdAccessor;
import org.objectweb.jorm.pobject.singlename.ASingleBigIntegerIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeByteIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeCharIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeShortIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeIntIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeLongIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeObyteIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeOcharIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeOshortIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeOintIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeOlongIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeStringIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeDateIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeBigDecimalIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeBigIntegerIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeBytearrayIdAccessor;
import org.objectweb.jorm.pobject.compositename.ACompositeChararrayIdAccessor;
import org.objectweb.jorm.naming.api.PName;

import java.util.Date;
import java.math.BigInteger;
import java.math.BigDecimal;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class NameDefAccessor
        implements
        ASingleByteIdAccessor,
        ASingleCharIdAccessor,
        ASingleShortIdAccessor,
        ASingleIntIdAccessor,
        ASingleLongIdAccessor,
        ASingleObyteIdAccessor,
        ASingleOcharIdAccessor,
        ASingleOshortIdAccessor,
        ASingleOintIdAccessor,
        ASingleOlongIdAccessor,
        ASingleStringIdAccessor,
		ASingleDateIdAccessor,
		ASingleBigDecimalIdAccessor,
		ASingleBigIntegerIdAccessor,
        ASingleBytearrayIdAccessor,
        ASingleChararrayIdAccessor,
        ACompositeByteIdAccessor,
        ACompositeCharIdAccessor,
        ACompositeShortIdAccessor,
        ACompositeIntIdAccessor,
        ACompositeLongIdAccessor,
        ACompositeObyteIdAccessor,
        ACompositeOcharIdAccessor,
        ACompositeOshortIdAccessor,
        ACompositeOintIdAccessor,
        ACompositeOlongIdAccessor,
        ACompositeStringIdAccessor,
		ACompositeDateIdAccessor,
		ACompositeBigDecimalIdAccessor,
		ACompositeBigIntegerIdAccessor,
        ACompositeBytearrayIdAccessor,
        ACompositeChararrayIdAccessor,
        PAccessor {

    public int f1;
    public Object value;
    public PName myself1 = null;
    public PName myself2 = null;

    public NameDefAccessor() {
    }

    public NameDefAccessor(int f1) {
        this.f1 = f1;
    }

    public NameDefAccessor(int f1, PName myself1, PName myself2) {
        this.f1 = f1;
        this.myself1 = myself1;
        this.myself2 = myself2;
    }

    public NameDefAccessor(int f1, Object value) {
        this.f1 = f1;
        this.value = value;
    }

    public NameDefAccessor(int f1, Object value, PName myself1, PName myself2) {
        this.f1 = f1;
        this.value = value;
        this.myself1 = myself1;
        this.myself2 = myself2;
    }

    public void paSetF1(int val) throws PException {
        f1 = val;
    }

    public int paGetF1() throws PException {
        return f1;
    }

    //Accessors to the myself field
    public void paSetMyself1(PName val, Object connection) throws PException {
        myself1 = val;
    }

    public PName paGetMyself1(Object connection) throws PException {
        return myself1;
    }

    //Accessors to the myself field
    public void paSetMyself2(PName val, Object connection) throws PException {
        myself2 = val;
    }

    public PName paGetMyself2(Object connection) throws PException {
        return myself2;
    }

    // IMPEMENTATION OF THE PAccessor INTERFACE //
    //------------------------------------------//

    public Object getMemoryInstance() {
        return null;
    }

    // IMPLEMENTATION OF THE ACompositeByteIdAccessor INTERFACE //
    //----------------------------------------------------------//

    public void paSetNameByte(byte val) throws PException {
        value = new Byte(val);
    }

    public byte paGetNameByte() throws PException {
        return ((Byte) value).byteValue();
    }

    // IMPLEMENTATION OF THE ACompositeCharIdAccessor INTERFACE //
    //----------------------------------------------------------//

    public void paSetNameChar(char val) throws PException {
        value = new Character(val);
    }

    public char paGetNameChar() throws PException {
        return ((Character) value).charValue();
    }

    // IMPLEMENTATION OF THE ACompositeShortIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameShort(short val) throws PException {
        value = new Short(val);
    }

    public short paGetNameShort() throws PException {
        return ((Short) value).shortValue();
    }

    // IMPLEMENTATION OF THE ACompositeIntIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameInt(int val) throws PException {
        value = new Integer(val);
    }

    public int paGetNameInt() throws PException {
        return ((Integer) value).intValue();
    }

    // IMPLEMENTATION OF THE ACompositeIntIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameLong(long val) throws PException {
        value = new Long(val);
    }

    public long paGetNameLong() throws PException {
        return ((Long) value).longValue();
    }

    // IMPLEMENTATION OF THE ACompositeObyteIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameObyte(Byte val) throws PException {
        value = val;
    }

    public Byte paGetNameObyte() throws PException {
        return (Byte) value;
    }

    // IMPLEMENTATION OF THE ACompositeOcharIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameOchar(Character val) throws PException {
        value = val;
    }

    public Character paGetNameOchar() throws PException {
        return (Character) value;
    }

    // IMPLEMENTATION OF THE ACompositeOshortIdAccessor INTERFACE //
    //------------------------------------------------------------//

    public void paSetNameOshort(Short val) throws PException {
        value = val;
    }

    public Short paGetNameOshort() throws PException {
        return (Short) value;
    }

    // IMPLEMENTATION OF THE ACompositeOintIdAccessor INTERFACE //
    //----------------------------------------------------------//

    public void paSetNameOint(Integer val) throws PException {
        value = val;
    }

    public Integer paGetNameOint() throws PException {
        return (Integer) value;
    }

    // IMPLEMENTATION OF THE ACompositeOlongIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameOlong(Long val) throws PException {
        value = val;
    }

    public Long paGetNameOlong() throws PException {
        return (Long) value;
    }

    // IMPLEMENTATION OF THE ACompositeStringIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameString(String val) throws PException {
        value = val;
    }

    public String paGetNameString() throws PException {
        return (String) value;
    }

	// IMPLEMENTATION OF THE ACompositeDateIdAccessor INTERFACE //
	//-----------------------------------------------------------//

	public void paSetNameDate(Date val) throws PException {
		value = val;
	}

	public Date paGetNameDate() throws PException {
		return (Date) value;
	}

	// IMPLEMENTATION OF THE ACompositeBigDecimalIdAccessor INTERFACE //
	//-----------------------------------------------------------//

	public void paSetNameBigDecimal(BigDecimal val) throws PException {
		value = val;
	}

	public BigDecimal paGetNameBigDecimal() throws PException {
		return (BigDecimal) value;
	}

	// IMPLEMENTATION OF THE ACompositeBigIntegerIdAccessor INTERFACE //
	//-----------------------------------------------------------//

	public void paSetNameBigInteger(BigInteger val) throws PException {
		value = val;
	}

	public BigInteger paGetNameBigInteger() throws PException {
		return (BigInteger) value;
	}

    // IMPLEMENTATION OF THE ACompositeBytearrayIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameBytearray(byte[] val) throws PException {
        value = val;
    }

    public byte[] paGetNameBytearray() throws PException {
        return (byte[]) value;
    }

    // IMPLEMENTATION OF THE ACompositeChararrayIdAccessor INTERFACE //
    //-----------------------------------------------------------//

    public void paSetNameChararray(char[] val) throws PException {
        value = val;
    }

    public char[] paGetNameChararray() throws PException {
        return (char[]) value;
    }
}
