/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.type;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PExceptionTyping;
import org.objectweb.jorm.type.lib.PTypeSpacePAAH;
import org.objectweb.jorm.api.PException;

/**
 * This class is used to test the PTypeSpacePAAH.
 *
 * @author S.Chassande-Barrioz
 */
public class TestPTypeSpace extends TestCase {
    /**
     * Main method to launch the tests manually.
     */
    public static void main(String[] args) {
        TestRunner.run(suite());
    }

    /**
     * This method creates a TestSuite object with the current tests
     */
    public static Test suite() {
        return new TestSuite(TestPTypeSpace.class);
    }

    protected PTypeSpace ptypeSpace = null;

    /**
     * Main constructor for the current object.
     */
    public TestPTypeSpace(String name) {
        super(name);
    }

    protected void setUp() throws Exception {
        ptypeSpace = new PTypeSpacePAAH();
    }

    protected void tearDown() throws Exception {
    }

    public void testIsa() {
        PType titi = null;
        PType toto = null;
        try {
            titi = ptypeSpace.createPType("titi", new String[][]{});
            assertNotNull("Simple class definition is null", titi);
            String[] z = new String[]{"toto", "titi"};
            String[][] r = new String[1][];
            r[0] = z;
            toto = ptypeSpace.createPType("toto", r);
            assertNotNull("Class definition with inheritance is null", toto);
        }
        catch (PExceptionTyping typing) {
            printException(typing);
            fail(typing.getMessage());
        }
        assertTrue("same PType", titi.isa(titi));
        assertTrue("same PType", toto.isa(toto));
        //assertTrue("Inheritance does not work", !titi.isa(toto));
        assertTrue("Inheritance does not work", toto.isa(titi));

        PType a = null;
        PType b = null;
        try {
            a = ptypeSpace.createPType("a",
                new String[][]{new String[]{"a", "b"}});
            b = ptypeSpace.createPType("b", new String[][]{});
        }
        catch (PExceptionTyping typing) {
            printException(typing);
            fail(typing.getMessage());
        }
        assertNotNull("Class definition with inheritance is null", a);
        assertNotNull("Simple class definition is null", b);
        assertTrue("reverse order definition does not work", a.isa(b));
    }

    private static void printException(Exception e) {
        if (e instanceof PException && ((PException) e).getNestedException()!=null) {
            System.out.println(e.getMessage());
            printException(((PException) e).getNestedException());
        }
        else
            e.printStackTrace();
    }
}
